==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_76.js <==
var searchData=
[
  ['v',['v',['../structistack.html#aa16f1de69ad69cef22523e46b69976ab',1,'istack']]],
  ['valid',['valid',['../struct__state.html#a2e5f4c9cc7b0ff82ba23766dac58204d',1,'_state']]],
  ['value',['value',['../structDrvOptCmd.html#a45e27167abb7d52c9f22d06a144400e8',1,'DrvOptCmd']]],
  ['var',['var',['../structplplot_1_1__N1.html#aa2903ee8ff4439e41d8aba6a5c477a33',1,'plplot::_N1::var()'],['../structPLOptionTable.html#a32667c6db2c9c085b99dbe120752ab32',1,'PLOptionTable::var()']]],
  ['var_5fptr',['var_ptr',['../structDrvOpt.html#ab48b331f2fc06df0473f3c3ef8ba0c5e',1,'DrvOpt']]],
  ['variable',['variable',['../namespacePlframe.html#aa53a94bcb2dc7836b90dee11786bf642',1,'Plframe']]],
  ['vars',['vars',['../structswig__varlinkobject.html#a8cf96d999cdf0b28a0e90ccb6804c9bd',1,'swig_varlinkobject']]],
  ['verbose',['verbose',['../structPLStream.html#a2218011a15ee0bdcd5fdd5163d25d954',1,'PLStream']]],
  ['vertices',['vertices',['../structtriangle.html#a7bf0a0839ddf5997308f85b028801f25',1,'triangle::vertices()'],['../structnn__weights.html#aa342a7ebce970a8cfc3e4f752d23b607',1,'nn_weights::vertices()'],['../structnnpi.html#a7a90b61915c9b408b76a105b2786f1cd',1,'nnpi::vertices()']]],
  ['vids',['vids',['../structtriangle.html#a60d5a93bca4b2fb019932aead96fa1f6',1,'triangle']]],
  ['visual',['visual',['../structTkwDisplay.html#a5a5fb1c781cc45c9055ac65f98b97b37',1,'TkwDisplay::visual()'],['../structXwDisplay.html#a0a424f8e4ea00519c492925867e49e3a',1,'XwDisplay::visual()']]],
  ['vpdxma',['vpdxma',['../structPLStream.html#a70f57c71ace3618b3d393496450096f3',1,'PLStream']]],
  ['vpdxmi',['vpdxmi',['../structPLStream.html#a8d7fc700a977b22e669939c96dcb24fc',1,'PLStream']]],
  ['vpdyma',['vpdyma',['../structPLStream.html#acf6d7c8a591d67fcdef0dd07e00c6cf3',1,'PLStream']]],
  ['vpdymi',['vpdymi',['../structPLStream.html#a6d63bdc61fc7bf5f3328e31df9cff1d2',1,'PLStream']]],
  ['vppxma',['vppxma',['../structPLStream.html#aa6c4b778304c44688e3bfee6b24ece84',1,'PLStream']]],
  ['vppxmi',['vppxmi',['../structPLStream.html#ae2b822caa7597bbf6158104568d4ff14',1,'PLStream']]],
  ['vppyma',['vppyma',['../structPLStream.html#a20e110cfacd22bf3f85bb0d1ba81e324',1,'PLStream']]],
  ['vppymi',['vppymi',['../structPLStream.html#a3be05ca8e59d93438f257e19eb2cbd68',1,'PLStream']]],
  ['vpwxma',['vpwxma',['../structPLStream.html#a0c3a6a8d591229bf49231b4a6c127730',1,'PLStream']]],
  ['vpwxmi',['vpwxmi',['../structPLStream.html#aa327cbb591b00e5f6be66c40e7eabea4',1,'PLStream']]],
  ['vpwyma',['vpwyma',['../structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23',1,'PLStream']]],
  ['vpwymi',['vpwymi',['../structPLStream.html#a2bbfa128180249ba951262bc3bd7ab1e',1,'PLStream']]],
  ['vtmp',['vtmp',['../plot3d_8c.html#a9ab85a15b7c7257de71ca5225299162b',1,'plot3d.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_76.js <==
var searchData=
[
  ['v',['v',['../structistack.html#aa16f1de69ad69cef22523e46b69976ab',1,'istack']]],
  ['valid',['valid',['../struct__state.html#a2e5f4c9cc7b0ff82ba23766dac58204d',1,'_state']]],
  ['value',['value',['../structDrvOptCmd.html#a45e27167abb7d52c9f22d06a144400e8',1,'DrvOptCmd']]],
  ['var',['var',['../structplplot_1_1__N1.html#aa2903ee8ff4439e41d8aba6a5c477a33',1,'plplot::_N1::var()'],['../structPLOptionTable.html#a023fced070b6f764fd16ff2c373d7eca',1,'PLOptionTable::var()']]],
  ['var_5fptr',['var_ptr',['../structDrvOpt.html#ab48b331f2fc06df0473f3c3ef8ba0c5e',1,'DrvOpt']]],
  ['variable',['variable',['../namespacePlframe.html#aa53a94bcb2dc7836b90dee11786bf642',1,'Plframe']]],
  ['vars',['vars',['../structswig__varlinkobject.html#a8cf96d999cdf0b28a0e90ccb6804c9bd',1,'swig_varlinkobject']]],
  ['verbose',['verbose',['../structPLStream.html#a2218011a15ee0bdcd5fdd5163d25d954',1,'PLStream']]],
  ['version',['version',['../structPLmDev.html#a8263ce61819daf74e22aaf4df9e85938',1,'PLmDev']]],
  ['vertices',['vertices',['../structtriangle.html#a7bf0a0839ddf5997308f85b028801f25',1,'triangle::vertices()'],['../structnn__weights.html#aa342a7ebce970a8cfc3e4f752d23b607',1,'nn_weights::vertices()'],['../structnnpi.html#a7a90b61915c9b408b76a105b2786f1cd',1,'nnpi::vertices()']]],
  ['vids',['vids',['../structtriangle.html#a60d5a93bca4b2fb019932aead96fa1f6',1,'triangle']]],
  ['vieweropenflag',['viewerOpenFlag',['../structMemoryMapHeader.html#af13b6442fe320dad8f30fd21f731671b',1,'MemoryMapHeader']]],
  ['visual',['visual',['../structTkwDisplay.html#a5a5fb1c781cc45c9055ac65f98b97b37',1,'TkwDisplay::visual()'],['../structXwDisplay.html#a0a424f8e4ea00519c492925867e49e3a',1,'XwDisplay::visual()']]],
  ['vpdxma',['vpdxma',['../structPLStream.html#a70f57c71ace3618b3d393496450096f3',1,'PLStream']]],
  ['vpdxmi',['vpdxmi',['../structPLStream.html#a8d7fc700a977b22e669939c96dcb24fc',1,'PLStream']]],
  ['vpdyma',['vpdyma',['../structPLStream.html#acf6d7c8a591d67fcdef0dd07e00c6cf3',1,'PLStream']]],
  ['vpdymi',['vpdymi',['../structPLStream.html#a6d63bdc61fc7bf5f3328e31df9cff1d2',1,'PLStream']]],
  ['vppxma',['vppxma',['../structPLStream.html#aa6c4b778304c44688e3bfee6b24ece84',1,'PLStream']]],
  ['vppxmi',['vppxmi',['../structPLStream.html#ae2b822caa7597bbf6158104568d4ff14',1,'PLStream']]],
  ['vppyma',['vppyma',['../structPLStream.html#a20e110cfacd22bf3f85bb0d1ba81e324',1,'PLStream']]],
  ['vppymi',['vppymi',['../structPLStream.html#a3be05ca8e59d93438f257e19eb2cbd68',1,'PLStream']]],
  ['vpwxma',['vpwxma',['../structPLStream.html#a0c3a6a8d591229bf49231b4a6c127730',1,'PLStream']]],
  ['vpwxmi',['vpwxmi',['../structPLStream.html#aa327cbb591b00e5f6be66c40e7eabea4',1,'PLStream']]],
  ['vpwyma',['vpwyma',['../structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23',1,'PLStream']]],
  ['vpwymi',['vpwymi',['../structPLStream.html#a2bbfa128180249ba951262bc3bd7ab1e',1,'PLStream']]],
  ['vtmp',['vtmp',['../plot3d_8c.html#a9ab85a15b7c7257de71ca5225299162b',1,'plot3d.c']]]
];
